@@ -108,8 +108,9 @@ different sets of packages."""
     p.add_argument(
         '--keep-old-work',
         action='store_true',
-        dest='dirty',
-        help="Deprecated.  Same as --dirty."
+        dest='keep_old_work',
+        help="Do not remove anything from environment, even after successful"
+             "build and test."
     )
     p.add_argument(
         '--dirty',
@@ -135,6 +136,13 @@ different sets of packages."""
         '--user',
         help="User/organization to upload packages to on anaconda.org or pypi"
     )
+    p.add_argument(
+        '--no-force-upload',
+        help="Disable force upload to anaconda.org, preventing overwriting any existing packages",
+        dest='force_upload',
+        default=True,
+        action='store_false',
+    )
     pypi_grp = p.add_argument_group("PyPI upload parameters (twine)")
     pypi_grp.add_argument(
         '--password',
