@@ -15,7 +15,7 @@ import time
 from .conda_interface import root_dir, root_writable, subdir, cc_platform, cc_conda_build
 from .conda_interface import string_types, binstar_upload
 
-from .utils import get_build_folders, rm_rf
+from .utils import get_build_folders, rm_rf, get_conda_operation_locks
 
 on_win = (sys.platform == 'win32')
 DEFAULT_PREFIX_LENGTH = 255
@@ -91,6 +91,7 @@ class Config(object):
         Setting = namedtuple("ConfigSetting", "name, default")
         values = [Setting('activate', True),
                   Setting('anaconda_upload', binstar_upload),
+                  Setting('force_upload', cc_conda_build.get('force_upload', True)),
                   Setting('channel_urls', []),
                   Setting('dirty', False),
                   Setting('include_recipe', True),
@@ -113,6 +114,7 @@ class Config(object):
                   Setting('locking', True),
                   Setting('max_env_retry', 3),
                   Setting('remove_work_dir', True),
+                  Setting('keep_old_work', False),
 
                   # pypi upload settings (twine)
                   Setting('password', None),
@@ -214,11 +216,12 @@ class Config(object):
 
     def _get_perl(self, prefix):
         if sys.platform == 'win32':
-            res = join(prefix, 'perl.exe')
+            res = join(prefix, 'Library', 'bin', 'perl.exe')
         else:
             res = join(prefix, 'bin/perl')
         return res
 
+    # TODO: This is probably broken on Windows, but no one has a lua package on windows to test.
     def _get_lua(self, prefix):
         binary_name = "luajit" if "2" == self.CONDA_LUA[0] else "lua"
         if sys.platform == 'win32':
@@ -408,16 +411,30 @@ class Config(object):
         _ensure_dir(path)
         return path
 
-    def clean(self):
+    def clean(self, remove_folders=True):
         # build folder is the whole burrito containing envs and source folders
         #   It will only exist if we download source, or create a build or test environment
-        if self.build_id:
-            if os.path.isdir(self.build_folder):
-                rm_rf(self.build_folder)
+        if remove_folders and not getattr(self, 'dirty'):
+            if self.build_id:
+                if os.path.isdir(self.build_folder):
+                    rm_rf(self.build_folder)
+            else:
+                for path in [self.work_dir, self.test_dir, self.build_prefix, self.test_prefix]:
+                    if os.path.isdir(path):
+                        rm_rf(path)
+            if os.path.isfile(os.path.join(self.build_folder, 'prefix_files')):
+                rm_rf(os.path.join(self.build_folder, 'prefix_files'))
         else:
-            for path in [self.work_dir, self.test_dir, self.build_prefix, self.test_prefix]:
-                if os.path.isdir(path):
-                    rm_rf(path)
+            print("\nLeaving build/test directories:"
+                  "\n  Work:\t", os.path.relpath(self.work_dir),
+                  "\n  Test:\t", os.path.relpath(self.test_dir),
+                  "\nLeaving build/test environments:"
+                  "\n  Test:\tsource activate ", os.path.relpath(self.test_prefix),
+                  "\n  Build:\tsource activate ", os.path.relpath(self.build_prefix),
+                  "\n\n")
+
+        for lock in get_conda_operation_locks(self):
+            rm_rf(lock.lock_file)
 
     def clean_pkgs(self):
         for folder in self.bldpkgs_dirs:
@@ -429,9 +446,12 @@ class Config(object):
 
     def __exit__(self, e_type, e_value, traceback):
         if not getattr(self, 'dirty') and e_type is None:
-            logging.getLogger(__name__).info("--dirty flag not specified.  Removing build"
-                                             " folder after successful build/test.\n")
-            self.clean()
+            if not getattr(self, 'keep_old_work'):
+                logging.getLogger(__name__).info("--dirty flag and --keep-old-work not specified."
+                                        "Removing build/test folder after successful build/test.\n")
+                self.clean()
+            else:
+                self.clean(remove_folders=False)
 
     def copy(self):
         new = copy.copy(self)
