@@ -252,6 +252,7 @@ def conda_build_vars(prefix, config):
         'SRC_DIR': src_dir,
         'HTTPS_PROXY': os.getenv('HTTPS_PROXY', ''),
         'HTTP_PROXY': os.getenv('HTTP_PROXY', ''),
+        'REQUESTS_CA_BUNDLE': os.getenv('REQUESTS_CA_BUNDLE', ''),
         'DIRTY': '1' if config.dirty else '',
         'ROOT': root_dir,
     }
@@ -445,6 +446,7 @@ def unix_vars(prefix):
         'HOME': os.getenv('HOME', 'UNKNOWN'),
         'PKG_CONFIG_PATH': join(prefix, 'lib', 'pkgconfig'),
         'CMAKE_GENERATOR': 'Unix Makefiles',
+        'SSL_CERT_FILE': os.getenv('SSL_CERT_FILE', ''),
     }
 
 
