@@ -317,7 +317,7 @@ FIELDS = {
     'app': ['entry', 'icon', 'summary', 'type', 'cli_opts',
             'own_environment'],
     'test': ['requires', 'commands', 'files', 'imports', 'source_files'],
-    'about': ['home', 'dev_url', 'doc_url', 'license_url',  # these are URLs
+    'about': ['home', 'dev_url', 'doc_url', 'doc_source_url', 'license_url',  # these are URLs
               'license', 'summary', 'description', 'license_family',  # text
               'license_file', 'readme',  # paths in source tree
               ],
@@ -488,7 +488,8 @@ class MetaData(object):
         run_reqs = reqs.get('run', [])
         # build_reqs = reqs.get('build', [])
         if bool(self.get_value('build/osx_is_app', False)) and self.config.platform == 'osx':
-            run_reqs.append('python.app')
+            if 'python.app' not in run_reqs:
+                run_reqs.append('python.app')
         self.meta['requirements'] = reqs
 
     def parse_until_resolved(self, config):
@@ -698,6 +699,10 @@ class MetaData(object):
             if value:
                 d[key] = value
 
+        preferred_env = self.get_value('build/preferred_env')
+        if preferred_env:
+            d['preferred_env'] = preferred_env
+
         if self.get_value('build/features'):
             d['features'] = ' '.join(self.get_value('build/features'))
         if self.get_value('build/track_features'):
@@ -854,8 +859,13 @@ class MetaData(object):
 
     @property
     def uses_setup_py_in_meta(self):
-        with open(self.meta_path) as f:
-            meta_text = f.read()
+        meta_path = (self.meta_path or
+                     self.meta.get('extra', {}).get('parent_recipe', {}).get('path'))
+        if meta_path:
+            with open(self.meta_path) as f:
+                meta_text = f.read()
+        else:
+            meta_text = ''
         return "load_setup_py_data" in meta_text or "load_setuptools" in meta_text
 
     @property
@@ -969,6 +979,18 @@ class MetaData(object):
             output_metadata.meta['extra'] = extra
         output_metadata.noarch = output.get('noarch')
         output_metadata.noarch_python = output.get('noarch_python')
+        build = output_metadata.meta.get('build', {})
+        if 'entry_points' in output:
+            build['entry_points'] = output['entry_points']
+        elif 'entry_points' in output:
+            del output['entry_points']
+        output_metadata.meta['build'] = build
+        test = output_metadata.meta.get('test', {})
+        if not output.get('name') == self.name():
+            if 'commands' in test:
+                del test['commands']
+            if 'imports' in test:
+                del test['imports']
         return output_metadata
 
     def get_output_metadata_set(self, files, permit_undefined_jinja=False):
@@ -991,7 +1013,6 @@ class MetaData(object):
                 # but only if a matching output name is not explicitly provided
                 if uses_subpackage and not any(self.name() == out.get('name', '')
                                                for out in outputs):
-
                     outputs.append({'name': self.name(), 'requirements': requirements,
                                     'pin_downstream':
                                         self.meta.get('build', {}).get('pin_downstream'),
