@@ -27,6 +27,7 @@ from .conda_interface import md5_file
 from .conda_interface import PY3
 
 from conda_build import utils
+from conda_build.environ import get_py_ver
 
 if sys.platform.startswith('linux'):
     from conda_build.os_utils import elf
@@ -90,7 +91,7 @@ def fix_shebang(f, prefix, build_python, osx_is_app=False):
 
 def write_pth(egg_path, config):
     fn = basename(egg_path)
-    with open(join(utils.get_site_packages(config.build_prefix),
+    with open(join(utils.get_site_packages(config.build_prefix, get_py_ver(config)),
                    '%s.pth' % (fn.split('-')[0])), 'w') as fo:
         fo.write('./%s\n' % fn)
 
@@ -101,7 +102,8 @@ def remove_easy_install_pth(files, prefix, config, preserve_egg_dir=False):
     itself
     """
     absfiles = [join(prefix, f) for f in files]
-    sp_dir = utils.get_site_packages(prefix)
+    py_ver = get_py_ver(config)
+    sp_dir = utils.get_site_packages(prefix, py_ver)
     for egg_path in glob(join(sp_dir, '*-py*.egg')):
         if isdir(egg_path):
             if preserve_egg_dir or not any(join(egg_path, i) in absfiles for i
@@ -355,7 +357,7 @@ def mk_relative_linux(f, prefix, rpaths=('lib',)):
     existing = existing.split(os.pathsep)
     new = []
     for old in existing:
-        if old.startswith('$ORIGIN/'):
+        if old.startswith('$ORIGIN'):
             new.append(old)
         elif old.startswith('/'):
             # Test if this absolute path is outside of prefix. That is fatal.
